@@ -105,16 +105,49 @@ class TestFeatureToggleAppConfig(TestCase):
         ]
     )
     @patch("samtranslator.feature_toggle.feature_toggle.boto3")
+    @patch("samtranslator.feature_toggle.feature_toggle.Config")
     def test_feature_toggle_with_appconfig_provider(
-        self, feature_name, stage, region, account_id, expected, boto3_mock
+        self, feature_name, stage, region, account_id, expected, config_mock, boto3_mock
     ):
         boto3_mock.client.return_value = self.app_config_mock
+        config_object_mock = Mock()
+        config_mock.return_value = config_object_mock
         feature_toggle_config_provider = FeatureToggleAppConfigConfigProvider(
             "test_app_id", "test_env_id", "test_conf_id"
         )
         feature_toggle = FeatureToggle(
             feature_toggle_config_provider, stage=stage, region=region, account_id=account_id
         )
+        boto3_mock.client.assert_called_once_with("appconfig", config=config_object_mock)
+        self.assertEqual(feature_toggle.is_enabled(feature_name), expected)
+
+    @parameterized.expand(
+        [
+            param("feature-1", "beta", "default", "123456789123", False),
+            param("feature-1", "beta", "us-west-2", "123456789123", True),
+            param("feature-2", "beta", "us-west-2", "123456789123", False),  # because feature is missing
+            param("feature-1", "beta", "ap-south-1", "123456789124", False),  # because default is used
+            param("feature-1", "alpha", "us-east-1", "123456789123", False),  # non-exist stage
+            param("feature-1", "beta", "us-east-1", "123456789100", True),
+            param("feature-1", "beta", "us-east-1", "123456789123", False),
+            # any None for stage, region and account_id returns False
+            param("feature-1", None, None, None, False),
+            param("feature-1", "beta", None, None, False),
+            param("feature-1", "beta", "us-west-2", None, False),
+            param("feature-1", "beta", None, "123456789123", False),
+        ]
+    )
+    @patch("samtranslator.feature_toggle.feature_toggle.boto3")
+    def test_feature_toggle_with_appconfig_provider_and_app_config_client(
+        self, feature_name, stage, region, account_id, expected, boto3_mock
+    ):
+        feature_toggle_config_provider = FeatureToggleAppConfigConfigProvider(
+            "test_app_id", "test_env_id", "test_conf_id", self.app_config_mock
+        )
+        feature_toggle = FeatureToggle(
+            feature_toggle_config_provider, stage=stage, region=region, account_id=account_id
+        )
+        boto3_mock.client.assert_not_called()
         self.assertEqual(feature_toggle.is_enabled(feature_name), expected)
 
 
