@@ -33,3 +33,15 @@ class EventBridgeRuleSourceTests(TestCase):
         self.eb_event_source.DeadLetterConfig = dead_letter_config
         with self.assertRaises(InvalidEventException):
             self.eb_event_source.to_cloudformation(resource=self.state_machine)
+
+    def test_to_cloudformation_with_state(self):
+        self.eb_event_source.State = "DISABLED"
+        resources = self.eb_event_source.to_cloudformation(resource=self.state_machine)
+        state = resources[0].State
+        self.assertEqual(state, "DISABLED")
+
+    def test_name_when_provided(self):
+        self.eb_event_source.RuleName = "MyRule"
+        resources = self.eb_event_source.to_cloudformation(resource=self.state_machine)
+        event_rule = resources[0]
+        self.assertEqual(event_rule.Name, "MyRule")
